@@ -255,7 +255,8 @@ class BenchmarkDBResource(object):
                 "tester": results[0][14],
                 "test_key": group_key,
                 "environment": self._get_env_by_index(results[0][0]),
-                "confirm": results[0][15]
+                "confirm": results[0][15],
+                "dut": self._get_dut_information(results[0][16])
             }
             test_results.append(test)
         return test_results
